"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Alert;
exports.bootstrapColors = void 0;

var _core = require("@material-ui/core");

var _makeStyles = _interopRequireDefault(require("@material-ui/core/styles/makeStyles"));

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Emulates the bootstrap alert boxes
 */
const useStyles = (0, _makeStyles.default)(theme => {
  const bootstrapColors = {
    primary: {
      color: theme.palette.primary.dark,
      backgroundColor: (0, _core.fade)((0, _core.lighten)(theme.palette.primary.light, 0.7), 0.8),
      borderColor: (0, _core.fade)((0, _core.lighten)(theme.palette.primary.light, 0.5), 0.8)
    },
    secondary: {
      color: theme.palette.secondary.dark,
      backgroundColor: (0, _core.fade)((0, _core.lighten)(theme.palette.secondary.light, 0.7), 0.8),
      borderColor: (0, _core.fade)((0, _core.lighten)(theme.palette.secondary.light, 0.5), 0.8)
    },
    success: {
      color: "#155724",
      backgroundColor: (0, _core.fade)("#d4edda", 0.8),
      borderColor: (0, _core.fade)("#c3e6cb", 0.8)
    },
    danger: {
      color: "#721c24",
      backgroundColor: (0, _core.fade)("#f8d7da", 0.8),
      borderColor: (0, _core.fade)("#f5c6cb", 0.8)
    },
    warning: {
      color: "#856404",
      backgroundColor: (0, _core.fade)("#fff3cd", 0.8),
      borderColor: (0, _core.fade)("#ffeeba", 0.8)
    },
    info: {
      color: "#0c5460",
      backgroundColor: (0, _core.fade)("#d1ecf1", 0.8),
      borderColor: (0, _core.fade)("#bee5eb", 0.8)
    },
    light: {
      color: theme.palette.text.disabled,
      backgroundColor: (0, _core.fade)(theme.palette.background.default, 0.8),
      borderColor: theme.palette.divider
    },
    dark: {
      color: theme.palette.background.default,
      backgroundColor: (0, _core.fade)(theme.palette.text.secondary, 0.8),
      borderColor: theme.palette.divider
    }
  };

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "danger" : x.color];
  }

  return {
    root: {
      backgroundColor: x => getColor(x).backgroundColor,
      color: x => getColor(x).color,
      borderColor: x => getColor(x).borderColor,
      position: "relative",
      border: "1px solid",
      padding: ".75rem 1.25rem",
      borderRadius: ".25rem",
      width: "100%"
    }
  };
});
const bootstrapColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
exports.bootstrapColors = bootstrapColors;

function Alert(props) {
  const classes = useStyles(props);
  return _react.default.createElement("div", {
    className: classes.root
  }, props.children);
}

Alert.defaultProps = {
  variant: "danger"
};